@@ -9,16 +9,24 @@
 #'
 #' @examples
 #' sim_colony()
-sim_colony <- function(seed = NULL) {
+sim_colony <- function(tau = NULL, n0 = NULL, lambda = NULL, delta = NULL, tmax = 20, seed = NULL) {
   if(!is.null(seed)) {
     set.seed(seed)
   }
-  tau <- rnorm(1, 6.5, 1.87) #weeks
-  # tau = rnorm(1, 6.5, 1.87) * 7 #days
-  n0 <- abs(round(exp(rnorm(1, 3.25, 1.22))))
-  lambda <- exp(rnorm(1, 0.39, 0.28))
-  delta <- rnorm(1, 0.57, 0.17)
-  tmax <- 20 #weeks
+  if(is.null(tau)) {
+    tau <- rnorm(1, 6.5, 1.87) #weeks
+    # tau = rnorm(1, 6.5, 1.87) * 7 #days
+  }
+  if(is.null(n0)) {
+    n0 <- abs(round(exp(rnorm(1, 3.25, 1.22))))
+  }
+  if(is.null(lambda)) {
+    lambda <- exp(rnorm(1, 0.39, 0.28))
+  }
+  if(is.null(delta)) {
+    delta <- rnorm(1, 0.57, 0.17)
+  }
+  tmax <- tmax #weeks
   # tmax = 20*7 #days
 
   #initialize worker number
