@@ -1,34 +1,29 @@
+test_good <- test_df %>% filter(colony == 1)
+test_bad <- test_df %>% filter(colony == 7)
 
-testbees <- bombus %>% dplyr::filter(colony == 9)
 
-noswitch <-
-  bombus %>%
-  filter(colony == 9) %>%
-  #do something to get reliable convergence error
-  mutate(week = week * 1000000000)
-
-testcount <-
-  testbees %>%
+test_good_count <-
+  test_good %>%
   #fake count data
-  dplyr::mutate(count = as.integer(mass) - min(as.integer(mass)))
+  dplyr::mutate(count = (as.integer(mass) - min(as.integer(mass))) + 10)
 
 test_that("brkpt works", {
   expect_s3_class(
-    brkpt(testbees, t = week, formula = mass ~ week),
+    brkpt(test_good, t = week, formula = mass ~ week),
     "data.frame"
   )
 })
 
 test_that("brkpt works with more complicated formulas", {
   expect_s3_class(
-    brkpt(testbees, t = week, formula = mass ~ week + floral_resources),
+    brkpt(test_good, t = week, formula = mass ~ week + floral_resources),
     "data.frame"
   )
 })
 
 test_that("brkpt errors when tau optimization does not converge", {
   expect_error({
-    brkpt(noswitch, t = week, formula = d.mass ~ week)
+    brkpt(test_bad, t = week, formula = mass ~ week, tau_optim_maxit = 1)
     },
     "Search for optimal switchpoint did not converge"
   )
@@ -44,24 +39,25 @@ test_that("brkpt errors when tau optimization does not converge", {
 #   expect_is(date.model2$tau, "POSIXct")
 # })
 
+
+test_that("dots pass arguments to glm()", {
+  #this isn't a great test.  Just checks that there's no error.  Can't tell if additional arg actually worked
+  expect_s3_class(
+    brkpt(test_good, t = week, formula = mass ~ week, model = FALSE),
+    "data.frame"
+  )
+})
+
 test_that("brkpt works with poisson dist", {
   skip_on_cran()
-  count.model <- brkpt(testcount, t = week, formula = count ~ week, family = "poisson")
+  count.model <- brkpt(test_good_count, t = week, formula = count ~ week, family = "poisson")
   expect_s3_class(count.model, "data.frame")
   expect_s3_class(count.model$model[[1]], "glm")
 })
 
 test_that("brkpt works with overdispersed data and family = 'negbin'", {
-  negbin.model <- brkpt(testcount, t = week, formula = count ~ week, family = "negbin")
+  negbin.model <- brkpt(test_good_count, t = week, formula = count ~ week, family = "negbin")
   expect_s3_class(negbin.model, "data.frame")
   expect_s3_class(negbin.model$model[[1]], "negbin")
 })
 
-test_that("dots pass arguments to glm()", {
-  #this isn't a great test.  Just checks that there's no error.  Can't tell if additional arg actually worked
-  expect_s3_class(
-    brkpt(testbees, t = week, formula = mass ~ week, model = FALSE),
-    "data.frame"
-  )
-})
-
